import type { AccountId } from "../models/AccountId";
import type { ApiKey } from "../models/ApiKey";
import type { ApiKeyDetails } from "../models/ApiKeyDetails";
import type { ApiKeyType } from "../models/ApiKeyType";
import type { CreateApiKey } from "../models/CreateApiKey";
import type { DeleteApiKeyBatch } from "../models/DeleteApiKeyBatch";
export declare class ApiKeysService {
    /**
     * Creates a new public or secret API key for the account.
     * @param accountId
     * @param apiKeyType
     * @param requestBody
     * @returns ApiKeyDetails Success.
     * @throws ApiError
     */
    static createApiKey(accountId: AccountId, apiKeyType: ApiKeyType, requestBody: CreateApiKey): Promise<ApiKeyDetails>;
    /**
     * Deletes an API key from an account.
     * @param accountId
     * @param apiKey
     * @returns void
     * @throws ApiError
     */
    static deleteApiKey(accountId: AccountId, apiKey: ApiKey): Promise<void>;
    /**
     * Deletes multiple API keys from an account.
     * @param accountId
     * @param requestBody
     * @returns void
     * @throws ApiError
     */
    static deleteApiKeyBatch(accountId: AccountId, requestBody: DeleteApiKeyBatch): Promise<void>;
}
