/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { DeleteTransformationsBatch } from "../models/DeleteTransformationsBatch";
import type { MountExistingCache } from "../models/MountExistingCache";
import type { MountNewCache } from "../models/MountNewCache";
import type { TransformationDefinition } from "../models/TransformationDefinition";
import type { TransformationDefinitionData } from "../models/TransformationDefinitionData";
import type { TransformationDefinitionId } from "../models/TransformationDefinitionId";
import { request as __request } from "../core/request";

export class TransformationsService {
  /**
   * Creates a new transformation for the account.
   * @param accountId
   * @param requestBody
   * @returns TransformationDefinition Success.
   * @throws ApiError
   */
  public static async createTransformation(
    accountId: AccountId,
    requestBody: TransformationDefinitionData
  ): Promise<TransformationDefinition> {
    const result = await __request({
      method: "POST",
      path: `/v1/accounts/${accountId}/transformations`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Deletes multiple transformations from the account.
   * @param accountId
   * @param deleteMountedCaches
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async deleteTransformationBatch(
    accountId: AccountId,
    deleteMountedCaches: boolean,
    requestBody: DeleteTransformationsBatch
  ): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/accounts/${accountId}/transformations`,
      query: {
        deleteMountedCaches: deleteMountedCaches
      },
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Updates an existing transformation for the account.
   * @param accountId
   * @param transformationId
   * @param requestBody
   * @returns TransformationDefinition Success.
   * @throws ApiError
   */
  public static async updateTransformation(
    accountId: AccountId,
    transformationId: TransformationDefinitionId,
    requestBody: TransformationDefinitionData
  ): Promise<TransformationDefinition> {
    const result = await __request({
      method: "PUT",
      path: `/v1/accounts/${accountId}/transformations/${transformationId}`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Deletes a transformation from the account.
   * @param accountId
   * @param transformationId
   * @param deleteMountedCache
   * @returns void
   * @throws ApiError
   */
  public static async deleteTransformation(
    accountId: AccountId,
    transformationId: TransformationDefinitionId,
    deleteMountedCache: boolean
  ): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/accounts/${accountId}/transformations/${transformationId}`,
      query: {
        deleteMountedCache: deleteMountedCache
      },
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Updates the transformation to use a new empty cache.
   * @param accountId
   * @param transformationId
   * @param requestBody
   * @returns MountExistingCache Success.
   * @throws ApiError
   */
  public static async mountNewEmptyCache(
    accountId: AccountId,
    transformationId: TransformationDefinitionId,
    requestBody: MountNewCache
  ): Promise<MountExistingCache> {
    const result = await __request({
      method: "POST",
      path: `/v1/accounts/${accountId}/transformations/${transformationId}/cache`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Updates the transformation to use another existing cache.
   * @param accountId
   * @param transformationId
   * @param requestBody
   * @returns any Success.
   * @throws ApiError
   */
  public static async mountExistingCache(
    accountId: AccountId,
    transformationId: TransformationDefinitionId,
    requestBody: MountExistingCache
  ): Promise<any> {
    const result = await __request({
      method: "PUT",
      path: `/v1/accounts/${accountId}/transformations/${transformationId}/cache`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }
}
